import { FormSchema } from '@/components/Form';
import { BasicColumn } from '@/components/Table';
import { TableColumn } from 'ant-design-vue';
import { TreeItem } from '@/components/Tree';

export const designFormSchema: FormSchema[] = [
  {
    field: 'name',
    component: 'Input',
    componentProps: {
      placeholder: '输入关键字搜索',
    },
    colProps: { lg: 4, md: 4 },
  },
  {
    field: 'type',
    component: 'Select',
    componentProps: {
      placeholder: '任务类型',
      options: [
        {
          label: 'Shell任务',
          value: 'Shell任务',
        },
        {
          label: 'SQL任务',
          value: 'SQL任务',
        },
        {
          label: 'Python任务',
          value: 'Python任务',
        },
        {
          label: 'Java任务',
          value: 'Java任务',
        },
        {
          label: 'R任务',
          value: 'R任务',
        },
        {
          label: 'Scale任务',
          value: 'Scale任务',
        },
      ],
    },
    colProps: { lg: 4, md: 4 },
  },
];
export const designColumn: BasicColumn[] = [
  {
    title: '任务名称',
    dataIndex: 'name',
    colSpan: { lg: 10, md: 10 },
  },
  {
    title: '上游任务',
    dataIndex: 'task',
    colSpan: { lg: 10, md: 10 },
    slots: { customRender: 'task' },
  },
];
export const infoFormSchema: FormSchema[] = [
  {
    label: '名称',
    field: 'name',
    labelWidth: 150,
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '描述',
    field: 'txt',
    labelWidth: 150,
    component: 'InputTextArea',
    componentProps: {
      rows: '3',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '超时设置',
    field: 'overTime',
    labelWidth: 150,
    slot: 'overTime',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '错误重试',
    field: 'errorAgain',
    labelWidth: 150,
    slot: 'errorAgain',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '是否跳过',
    field: 'skip',
    labelWidth: 150,
    slot: 'skip',
    component: 'Checkbox',
    renderComponentContent: '开启',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '执行器组',
    field: 'group',
    labelWidth: 150,
    slot: 'group',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '独立调度',
    field: 'dispatch',
    labelWidth: 150,
    component: 'Checkbox',
    renderComponentContent: '开启',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '调度周期',
    field: 'cycle',
    required: true,
    labelWidth: 150,
    show: ({ model }) => {
      return model.dispatch;
    },
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '每天一次',
          value: '每天一次',
        },
        {
          label: '每周一次',
          value: '每周一次',
        },
        {
          label: '每月一次',
          value: '每月一次',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '调度时间',
    labelWidth: 150,
    required: true,
    field: 'time',
    slot: 'time',
    show: ({ model }) => {
      return model.dispatch && model.cycle;
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '当前任务执行前置条件',
    field: 'txt',
    labelWidth: 150,
    component: 'InputTextArea',
    componentProps: {
      rows: '3',
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const scriptFormSchema: FormSchema[] = [
  {
    label: '模式',
    field: 'type',
    defaultValue: '1',
    slot: 'type',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: 'Script',
    field: 'Script',
    component: 'InputTextArea',
    componentProps: {
      rows: 8,
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const scriptUploadFormSchema: FormSchema[] = [
  {
    label: '模式',
    field: 'type',
    defaultValue: '2',
    slot: 'type',
    colProps: { lg: 24, md: 24 },
  },
  // {
  //   label: '文件',
  //   field: 'file',
  //   component: 'Upload',
  //   colProps: { lg: 24, md: 24 },
  // },
  {
    label: '文件',
    field: 'file',
    slot: 'file',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '运行文件',
    field: 'runFile',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '程序参数',
    field: 'config',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
];
export const taskConfigColumn: BasicColumn[] = [
  {
    title: '参数名',
    dataIndex: 'name',
    slots: { customRender: 'name' },
  },
  {
    title: '参数类型',
    dataIndex: 'type',
    slots: { customRender: 'type' },
  },
  {
    title: '表达式',
    dataIndex: 'formula',
    slots: { customRender: 'formula' },
  },
];
export const sqlFormSchema: FormSchema[] = [
  {
    label: '模式',
    field: 'mode',
    defaultValue: '自定义任务',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '自定义任务',
          value: '自定义任务',
        },
        {
          label: '外部任务',
          value: '外部任务',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '数据源',
    field: 'dataSource',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '014-mysql',
          value: '014-mysql,',
        },
        {
          label: '013-mysql',
          value: '013-mysql,',
        },
        {
          label: '011-mysql',
          value: '011-mysql,',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: ' ',
    field: 'saveResult',
    slot: 'saveResult',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: 'SQL执行模式',
    field: 'runMode',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '不拆分执行',
          value: '不拆分执行',
        },
        {
          label: '拆分执行',
          value: '拆分执行',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: 'SQL',
    field: 'sql',
    show: ({ model }) => {
      return model.mode === '自定义任务';
    },
    component: 'InputTextArea',
    componentProps: {
      rows: 5,
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: 'SQL文件',
    field: 'sqlFile',
    show: ({ model }) => {
      return model.mode === '外部任务';
    },
    slot: 'sqlFile',
    componentProps: {
      options: [
        {
          label: '/SQL文件/共享工作区/test',
          value: '/SQL文件/共享工作区/test',
        },
        {
          label: '/SQL文件/共享工作区/sql1',
          value: '/SQL文件/共享工作区/sql1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'sqlPreview',
    defaultValue:
      'CREATE TABLE USER_TEST1_user(\n' +
      'ID int ,\n' +
      'PERSON_NAME_user varchar(10o) DEFAULT NULL,\n' +
      'AGE_user int DEFAULT NULL,\n' +
      'HEIGHT_user decimal(38,12) DEFAULT NULL,\n' +
      'GENDER_user varchar(1) DEFAULT NULL,\n' +
      'SCORE_user decimal(10,2) DEFAULT NULL,\n' +
      'ADDRESS_user varchar(1000) DEFAULT NULL,\n' +
      'COUNTRY_user varchar(10o)DEFAULT NULL,\n' +
      'CITY_uservarchar(10)DEFAULT NULL\n' +
      'EMAIL_user varchar(100) DEFAULT NULL,\n' +
      'ANIMAL_NAME_user varchar(10o) DEFAULT NULL,',
    show: ({ model }) => {
      return model.mode === '外部任务';
    },
    slot: 'sqlPreview',
    colProps: { lg: 24, md: 24 },
  },
];
export const pythonFormSchema: FormSchema[] = [
  {
    label: '模式',
    field: 'mode',
    defaultValue: '自定义',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '自定义',
          value: '自定义',
        },
        {
          label: '上传文件',
          value: '上传文件',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: 'Python',
    field: 'txt',
    show: ({ model }) => {
      return model.mode === '自定义';
    },
    component: 'InputTextArea',
    componentProps: {
      rows: 4,
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: 'Python文件',
    field: 'file',
    show: ({ model }) => {
      return model.mode === '上传文件';
    },
    slot: 'file',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '运行文件',
    field: 'runField',
    show: ({ model }) => {
      return model.mode === '上传文件';
    },
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: 'Python option',
    field: 'option',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '-m',
          value: '-m',
        },
        {
          label: '-c',
          value: '-c',
        },
        {
          label: '-O',
          value: '-O',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '运行参数',
    field: 'config',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '运行环境',
    field: 'setting',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'python3',
          value: 'python3',
        },
        {
          label: 'python2',
          value: 'python2',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const javaFormSchema: FormSchema[] = [
  {
    label: 'Java文件',
    field: 'file',
    slot: 'file',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '类名',
    field: 'class',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: 'Java option',
    field: 'option',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '程序参数',
    field: 'config',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '运行环境',
    field: 'setting',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'JAVA',
          value: 'JAVA',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const rFormSchema: FormSchema[] = [
  {
    label: '模式',
    field: 'mode',
    defaultValue: '编辑器',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '编辑器',
          value: '编辑器',
        },
        {
          label: '上传文件',
          value: '上传文件',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: 'R任务',
    field: 'task',
    show: ({ model }) => {
      return model.mode === '编辑器';
    },
    component: 'InputTextArea',
    componentProps: {
      rows: 4,
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: 'R文件',
    field: 'file',
    show: ({ model }) => {
      return model.mode === '上传文件';
    },
    slot: 'file',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '运行文件',
    field: 'runFile',
    show: ({ model }) => {
      return model.mode === '上传文件';
    },
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: 'R option',
    field: 'option',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '程序参数',
    field: 'config',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '运行环境',
    field: 'setting',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'R',
          value: 'R',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const scalaFormSchema: FormSchema[] = [
  {
    label: 'Scala文件',
    field: 'file',
    slot: 'file',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: 'Scala option',
    field: 'option',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '程序参数',
    field: 'config',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '运行环境',
    field: 'setting',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'java-agent',
          value: 'java-agent',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const dataQualityFormSchema: FormSchema[] = [
  {
    label: '数据质量',
    field: 'path',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '/质量任务',
          value: '/质量任务',
        },
      ],
    },
  },
  {
    label: '通过率不低于',
    field: 'perc',
    slot: 'perc',
    helpMessage: '通过率',
  },
];
export const dataLoadFormSchema: FormSchema[] = [
  {
    label: '数据加载',
    field: 'path',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '/数据加载',
          value: '/数据加载',
        },
      ],
    },
  },
];
export const dataSyncFormSchema: FormSchema[] = [
  {
    label: '数据同步',
    field: 'path',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '/数据同步',
          value: '/数据同步',
        },
      ],
    },
  },
];
export const dataIndexFormSchema: FormSchema[] = [
  {
    label: '数据指标',
    field: 'path',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '/数据指标',
          value: '/数据指标',
        },
      ],
    },
  },
];
export const labelCheckFormSchema: FormSchema[] = [
  {
    label: '落标检查',
    field: 'labelCheck',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '/落标检查',
          value: '/落标检查',
        },
      ],
    },
  },
  {
    label: '检查结果',
    field: 'check',
    helpMessage: '检查结果',
    component: 'CheckboxGroup',
    componentProps: {
      options: [
        {
          label: '所有规则均通过检查',
          value: '所有规则均通过检查',
        },
      ],
    },
  },
];
export const embedFlowFormSchema: FormSchema[] = [
  {
    label: '任务流',
    field: 'path',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '/任务流',
          value: '/任务流',
        },
      ],
    },
  },
];
export const delayFormSchema: FormSchema[] = [
  {
    label: '延时时间',
    field: 'time',
    slot: 'time',
  },
];
export const dataLoadConfigColumn: BasicColumn[] = [
  {
    title: '参数名',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '参数类型',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '表达式',
    dataIndex: 'formula',
    width: 120,
  },
  {
    title: '参数映射',
    dataIndex: 'config',
    edit: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'field1',
          value: 'field1',
        },
        {
          label: 'field2',
          value: 'field2',
        },
      ],
    },
    width: 120,
  },
];
// upstreamTaskModel
export const upstreamTaskColumn: BasicColumn[] = [
  {
    title: '上游任务',
    dataIndex: 'task',
    slots: { customRender: 'task' },
  },
  {
    title: '依赖关系',
    dataIndex: 'depend',
    slots: { customRender: 'depend' },
  },
];
export const taskFlushColumn: BasicColumn[] = [
  {
    title: '任务流名称',
    dataIndex: 'name',
    slots: { customRender: 'name' },
  },
  {
    title: '引用上游参数',
    dataIndex: 'config',
    slots: { customRender: 'config' },
  },
];
export const taskColumn: BasicColumn[] = [
  {
    title: '任务名称',
    dataIndex: 'name',
    slots: { customRender: 'name' },
  },
  {
    title: '引用上游参数',
    dataIndex: 'config',
    slots: { customRender: 'config' },
  },
];
export const taskOverallConfig: FormSchema[] = [
  {
    label: '名称',
    field: 'name',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '描述',
    field: 'txt',
    component: 'InputTextArea',
    componentProps: {
      rows: 4,
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '业务标签',
    field: 'tag',
    component: 'Select',
    componentProps: {
      mode: 'multiple',
      options: [
        {
          label: '临时',
          value: '临时',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '调度周期',
    field: 'cycle',
    slot: 'cycle',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: 'Cron表达式',
    field: 'cron',
    slot: 'cron',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '自定义日历',
    field: 'calendar',
    defaultValue: '不启用',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '启用',
          value: '启用',
        },
        {
          label: '不启用',
          value: '不启用',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '超时设置',
    field: 'overTime',
    slot: 'overTime',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '依赖上次',
    field: 'depend',
    defaultValue: '不依赖',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '不依赖',
          value: '不依赖',
        },
        {
          label: '上次成功',
          value: '上次成功',
        },
        {
          label: '上次完成',
          value: '上次完成',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '执行器组',
    field: 'group',
    slot: 'group',
    colProps: { lg: 24, md: 24 },
  },
  {
    label: '执行优先级',
    field: 'priority',
    component: 'RadioGroup',
    defaultValue: '低',
    componentProps: {
      options: [
        {
          label: '高',
          value: '高',
        },
        {
          label: '中',
          value: '中',
        },
        {
          label: '低',
          value: '低',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const editFormSchema: FormSchema[] = [
  {
    label: '刷新对象',
    field: 'flushType',
    required: true,
    component: 'CheckboxGroup',
    componentProps: {
      options: [
        {
          label: '调度配置',
          value: '调度配置',
        },
        {
          label: '日历',
          value: '日历',
        },
      ],
    },
  },
];
export const editTableColumn: BasicColumn[] = [
  {
    title: '资源对象',
    dataIndex: 'name',
    width: 200,
    slots: { customRender: 'name' },
  },
  {
    title: '调度配置',
    dataIndex: 'cron',
    width: 150,
    slots: { customRender: 'cron' },
  },
  {
    title: '发布状态',
    dataIndex: 'flag',
    width: 120,
  },
  {
    title: '日历配置',
    dataIndex: 'config',
    width: 150,
  },
];
export const editResultColumn: BasicColumn[] = [
  {
    title: '资源对象',
    dataIndex: 'name',
    width: 180,
    slots: { customRender: 'name' },
  },
  {
    title: '调度配置',
    dataIndex: 'cron',
    width: 100,
    slots: { customRender: 'cron' },
  },
  {
    title: '发布状态',
    dataIndex: 'flag',
    width: 100,
  },
  {
    title: '日历配置',
    dataIndex: 'config',
    width: 100,
  },
  {
    title: '发布状态',
    dataIndex: 'uploadStatus',
    width: 100,
  },
  {
    title: '更新状态',
    dataIndex: 'updateStatus',
    width: 100,
    slots: { customRender: 'updateStatus' },
  },
  {
    title: '详情',
    dataIndex: 'detail',
    width: 80,
  },
];
export const uploadModelSchema: FormSchema[] = [
  {
    label: '版本变更描述',
    field: 'txt',
    component: 'InputTextArea',
    componentProps: {
      rows: 4,
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const delTableColumn1: BasicColumn[] = [
  {
    dataIndex: 'task',
    width: 150,
  },
];
